package org.xtext.example.mydsl.serializer;

import com.google.inject.Inject;
import com.google.inject.Provider;
import org.eclipse.emf.ecore.EObject;
import org.eclipse.xtext.serializer.acceptor.ISemanticSequenceAcceptor;
import org.eclipse.xtext.serializer.acceptor.SequenceFeeder;
import org.eclipse.xtext.serializer.diagnostic.ISemanticSequencerDiagnosticProvider;
import org.eclipse.xtext.serializer.diagnostic.ISerializationDiagnostic.Acceptor;
import org.eclipse.xtext.serializer.sequencer.AbstractDelegatingSemanticSequencer;
import org.eclipse.xtext.serializer.sequencer.GenericSequencer;
import org.eclipse.xtext.serializer.sequencer.ISemanticNodeProvider.INodesForEObjectProvider;
import org.eclipse.xtext.serializer.sequencer.ISemanticSequencer;
import org.eclipse.xtext.serializer.sequencer.ITransientValueService;
import org.eclipse.xtext.serializer.sequencer.ITransientValueService.ValueTransient;
import org.xtext.example.mydsl.myDsl.Application;
import org.xtext.example.mydsl.myDsl.ArchFile;
import org.xtext.example.mydsl.myDsl.Building;
import org.xtext.example.mydsl.myDsl.Company;
import org.xtext.example.mydsl.myDsl.Department;
import org.xtext.example.mydsl.myDsl.MemorySpecification;
import org.xtext.example.mydsl.myDsl.MobileDevice;
import org.xtext.example.mydsl.myDsl.MyDslPackage;
import org.xtext.example.mydsl.myDsl.OperatingSystem;
import org.xtext.example.mydsl.myDsl.Person;
import org.xtext.example.mydsl.myDsl.ProxyService;
import org.xtext.example.mydsl.myDsl.Room;
import org.xtext.example.mydsl.myDsl.Server;
import org.xtext.example.mydsl.myDsl.SoftwareService;
import org.xtext.example.mydsl.myDsl.SystemSpecs;
import org.xtext.example.mydsl.myDsl.Workstation;
import org.xtext.example.mydsl.services.MyDslGrammarAccess;

@SuppressWarnings("all")
public class MyDslSemanticSequencer extends AbstractDelegatingSemanticSequencer {

	@Inject
	private MyDslGrammarAccess grammarAccess;
	
	public void createSequence(EObject context, EObject semanticObject) {
		if(semanticObject.eClass().getEPackage() == MyDslPackage.eINSTANCE) switch(semanticObject.eClass().getClassifierID()) {
			case MyDslPackage.APPLICATION:
				if(context == grammarAccess.getApplicationRule() ||
				   context == grammarAccess.getFragmentRule() ||
				   context == grammarAccess.getSoftwareComponentRule()) {
					sequence_Application(context, (Application) semanticObject); 
					return; 
				}
				else break;
			case MyDslPackage.ARCH_FILE:
				if(context == grammarAccess.getArchFileRule()) {
					sequence_ArchFile(context, (ArchFile) semanticObject); 
					return; 
				}
				else break;
			case MyDslPackage.BUILDING:
				if(context == grammarAccess.getBuildingRule() ||
				   context == grammarAccess.getFragmentRule() ||
				   context == grammarAccess.getLocationRule()) {
					sequence_Building(context, (Building) semanticObject); 
					return; 
				}
				else break;
			case MyDslPackage.COMPANY:
				if(context == grammarAccess.getCompanyRule() ||
				   context == grammarAccess.getFragmentRule() ||
				   context == grammarAccess.getOrganizationalComponentRule()) {
					sequence_Company(context, (Company) semanticObject); 
					return; 
				}
				else break;
			case MyDslPackage.DEPARTMENT:
				if(context == grammarAccess.getDepartmentRule() ||
				   context == grammarAccess.getFragmentRule() ||
				   context == grammarAccess.getOrganizationalComponentRule()) {
					sequence_Department(context, (Department) semanticObject); 
					return; 
				}
				else break;
			case MyDslPackage.MEMORY_SPECIFICATION:
				if(context == grammarAccess.getMemorySpecificationRule()) {
					sequence_MemorySpecification(context, (MemorySpecification) semanticObject); 
					return; 
				}
				else break;
			case MyDslPackage.MOBILE_DEVICE:
				if(context == grammarAccess.getFragmentRule() ||
				   context == grammarAccess.getHardwareComponentRule() ||
				   context == grammarAccess.getMobileDeviceRule()) {
					sequence_MobileDevice(context, (MobileDevice) semanticObject); 
					return; 
				}
				else break;
			case MyDslPackage.OPERATING_SYSTEM:
				if(context == grammarAccess.getFragmentRule() ||
				   context == grammarAccess.getOperatingSystemRule() ||
				   context == grammarAccess.getSoftwareComponentRule()) {
					sequence_OperatingSystem(context, (OperatingSystem) semanticObject); 
					return; 
				}
				else break;
			case MyDslPackage.PERSON:
				if(context == grammarAccess.getFragmentRule() ||
				   context == grammarAccess.getPersonRule()) {
					sequence_Person(context, (Person) semanticObject); 
					return; 
				}
				else break;
			case MyDslPackage.PROXY_SERVICE:
				if(context == grammarAccess.getFragmentRule() ||
				   context == grammarAccess.getProxyServiceRule() ||
				   context == grammarAccess.getServiceRule()) {
					sequence_ProxyService(context, (ProxyService) semanticObject); 
					return; 
				}
				else break;
			case MyDslPackage.ROOM:
				if(context == grammarAccess.getFragmentRule() ||
				   context == grammarAccess.getLocationRule() ||
				   context == grammarAccess.getRoomRule()) {
					sequence_Room(context, (Room) semanticObject); 
					return; 
				}
				else break;
			case MyDslPackage.SERVER:
				if(context == grammarAccess.getFragmentRule() ||
				   context == grammarAccess.getHardwareComponentRule() ||
				   context == grammarAccess.getServerRule()) {
					sequence_Server(context, (Server) semanticObject); 
					return; 
				}
				else break;
			case MyDslPackage.SOFTWARE_SERVICE:
				if(context == grammarAccess.getFragmentRule() ||
				   context == grammarAccess.getServiceRule() ||
				   context == grammarAccess.getSoftwareServiceRule()) {
					sequence_SoftwareService(context, (SoftwareService) semanticObject); 
					return; 
				}
				else break;
			case MyDslPackage.SYSTEM_SPECS:
				if(context == grammarAccess.getSystemSpecsRule()) {
					sequence_SystemSpecs(context, (SystemSpecs) semanticObject); 
					return; 
				}
				else break;
			case MyDslPackage.WORKSTATION:
				if(context == grammarAccess.getFragmentRule() ||
				   context == grammarAccess.getHardwareComponentRule() ||
				   context == grammarAccess.getWorkstationRule()) {
					sequence_Workstation(context, (Workstation) semanticObject); 
					return; 
				}
				else break;
			}
		if (errorAcceptor != null) errorAcceptor.accept(diagnosticProvider.createInvalidContextOrTypeDiagnostic(semanticObject, context));
	}
	
	/**
	 * Constraint:
	 *     (name=ID vendor=[Company|QualifiedName]? (productName=ID | productName=STRING)? version=SoftwareVersion?)
	 */
	protected void sequence_Application(EObject context, Application semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Constraint:
	 *     fragments+=Fragment*
	 */
	protected void sequence_ArchFile(EObject context, ArchFile semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Constraint:
	 *     (name=ID address=STRING owningCompany=[Company|QualifiedName]? rooms+=Room*)
	 */
	protected void sequence_Building(EObject context, Building semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Constraint:
	 *     (name=ID ceo=[Person|QualifiedName]? cio=[Person|QualifiedName]? headquarters=[Location|QualifiedName]?)
	 */
	protected void sequence_Company(EObject context, Company semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Constraint:
	 *     (name=ID company=[Company|QualifiedName] head=[Person|QualifiedName]?)
	 */
	protected void sequence_Department(EObject context, Department semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Constraint:
	 *     (amount=FloatingPoint unit=MemoryUnit)
	 */
	protected void sequence_MemorySpecification(EObject context, MemorySpecification semanticObject) {
		if(errorAcceptor != null) {
			if(transientValues.isValueTransient(semanticObject, MyDslPackage.Literals.MEMORY_SPECIFICATION__AMOUNT) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, MyDslPackage.Literals.MEMORY_SPECIFICATION__AMOUNT));
			if(transientValues.isValueTransient(semanticObject, MyDslPackage.Literals.MEMORY_SPECIFICATION__UNIT) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, MyDslPackage.Literals.MEMORY_SPECIFICATION__UNIT));
		}
		INodesForEObjectProvider nodes = createNodeProvider(semanticObject);
		SequenceFeeder feeder = createSequencerFeeder(semanticObject, nodes);
		feeder.accept(grammarAccess.getMemorySpecificationAccess().getAmountFloatingPointParserRuleCall_0_0(), semanticObject.getAmount());
		feeder.accept(grammarAccess.getMemorySpecificationAccess().getUnitMemoryUnitEnumRuleCall_1_0(), semanticObject.getUnit());
		feeder.finish();
	}
	
	
	/**
	 * Constraint:
	 *     (
	 *         name=ID 
	 *         systemSpecs=SystemSpecs 
	 *         owningCompany=[Company|QualifiedName]? 
	 *         (users+=[Person|QualifiedName] users+=[Person|QualifiedName]*)? 
	 *         (localSoftware+=[SoftwareComponent|QualifiedName] localSoftware+=[SoftwareComponent|QualifiedName]*)?
	 *     )
	 */
	protected void sequence_MobileDevice(EObject context, MobileDevice semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Constraint:
	 *     (name=ID (productName=ID | productName=STRING)? vendor=[Company|QualifiedName]? version=SoftwareVersion?)
	 */
	protected void sequence_OperatingSystem(EObject context, OperatingSystem semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Constraint:
	 *     (name=ID (firstName=ID | firstName=STRING) (lastName=ID | lastName=STRING) mailAddress=STRING)
	 */
	protected void sequence_Person(EObject context, Person semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Constraint:
	 *     (name=ID (portID=INT | url=URLRule) proxyTarget=[Service|QualifiedName])
	 */
	protected void sequence_ProxyService(EObject context, ProxyService semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Constraint:
	 *     name=ID
	 */
	protected void sequence_Room(EObject context, Room semanticObject) {
		if(errorAcceptor != null) {
			if(transientValues.isValueTransient(semanticObject, MyDslPackage.Literals.FRAGMENT__NAME) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, MyDslPackage.Literals.FRAGMENT__NAME));
		}
		INodesForEObjectProvider nodes = createNodeProvider(semanticObject);
		SequenceFeeder feeder = createSequencerFeeder(semanticObject, nodes);
		feeder.accept(grammarAccess.getRoomAccess().getNameIDTerminalRuleCall_1_0(), semanticObject.getName());
		feeder.finish();
	}
	
	
	/**
	 * Constraint:
	 *     (
	 *         name=ID 
	 *         systemSpecs=SystemSpecs 
	 *         location=[Location|QualifiedName]? 
	 *         owningCompany=[Company|QualifiedName]? 
	 *         (serverTypes+=ServerType serverTypes+=ServerType*)? 
	 *         services+=Service*
	 *     )
	 */
	protected void sequence_Server(EObject context, Server semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Constraint:
	 *     (name=ID visibility=Visibility? software=[SoftwareComponent|QualifiedName] (portID=INT | url=URLRule)?)
	 */
	protected void sequence_SoftwareService(EObject context, SoftwareService semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Constraint:
	 *     (
	 *         operatingSystem=[OperatingSystem|QualifiedName]? 
	 *         (cpu=ID | cpu=STRING)? 
	 *         ram=MemorySpecification? 
	 *         hdd=MemorySpecification? 
	 *         vendor=[Company|QualifiedName]? 
	 *         (deviceName=ID | deviceName=STRING)?
	 *     )
	 */
	protected void sequence_SystemSpecs(EObject context, SystemSpecs semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Constraint:
	 *     (
	 *         name=ID 
	 *         systemSpecs=SystemSpecs 
	 *         location=[Location|QualifiedName]? 
	 *         owningCompany=[Company|QualifiedName]? 
	 *         (users+=[Person|QualifiedName] users+=[Person|QualifiedName]*)? 
	 *         (localSoftware+=[SoftwareComponent|QualifiedName] localSoftware+=[SoftwareComponent|QualifiedName]*)?
	 *     )
	 */
	protected void sequence_Workstation(EObject context, Workstation semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
}
